/***************************************************************************
                          gphoto_messages.cpp  -  description
                             -------------------
    begin                : Sun Dec 30 2001
    copyright            : (C) 2001 by Renchi Raju
    email                : renchi@green.tam.uiuc.edu
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "gphoto_messages.h"

Gphoto_Messages* Gphoto_Messages::gpMessages=0;

Gphoto_Messages* Gphoto_Messages::gpMessagesWrapper() {

    if (!gpMessages) {
        gpMessages = new Gphoto_Messages;
    }
    return gpMessages;
}

void Gphoto_Messages::deleteMessagesWrapper()
{
    if (gpMessages) {
        delete gpMessages;
        gpMessages=0;
    }
}
